# Script préparant les aerosols pour DAMIP
# a partir des sorties de AER-ssp245
# annees 2015 a 2020
# Th. Lurton IPSL juil. 2018

#!/bin/sh

storechemin=/ccc/store/cont003/gencmip6/lurtont/IGCM_OUT/LMDZORINCA/PROD/scenarioAER/AER-ssp245/CHM/Output/MO/
workchemin=/ccc/work/cont003/gencmip6/lurtont/aerosols_from_inca/AER_for_DAMIP/

if [ ! -d ${workchemin} ] ; then mkdir -p ${workchemin} ; fi

histchemin=/ccc/store/cont003/gencmip6/lurtont/IGCM_OUT/LMDZORINCA/PROD/historicalAER/LOI6012-histAER-partE/CHM/Output/MO/

for year in {2015..2020}
do

echo "Je traite l'année "${year}"..."

# On effectue une moyenne glissante sur trois ans, centree en l'annee d'interet, et de poids [0.25 ; 0.5 ; 0.25].
# Pour 2015, on ira chercher le 2014 chez les AER-historicals.

prec=$((${year}-1))
suiv=$((${year}+1))

# Adresses generiques des fichiers-sources
fileprec=${storechemin}AER-ssp245_${prec}0101_${prec}1230_1M_aerosols_from_inca.nc
fileyear=${storechemin}AER-ssp245_${year}0101_${year}1230_1M_aerosols_from_inca.nc
filesuiv=${storechemin}AER-ssp245_${suiv}0101_${suiv}1230_1M_aerosols_from_inca.nc

# Petit override pour le cas 2015, vers le chemin de la simulation historical.
if [ ${year} = 2015 ]
then
echo "On est en 2015, je vais chercher 2014 chez les historiques."
fileprec=/ccc/store/cont003/gencmip6/lurtont/IGCM_OUT/LMDZORINCA/PROD/historicalAER/LOI6012-histAER-partE/CHM/Output/MO/LOI6012-histAER-partE_20140101_20141230_1M_aerosols_from_inca.nc
fi

# Fichiers temporaires avec pondération (cas générique)
pondprec=${workchemin}AER-ssp245_${prec}0101_${prec}1230_pond.nc
pondyear=${workchemin}AER-ssp245_${year}0101_${year}1230_pond.nc
pondsuiv=${workchemin}AER-ssp245_${suiv}0101_${suiv}1230_pond.nc

# Pondération des trois années successives par 1/4 ; 1/2 ; 1/4 ]
# et multiplication par un facteur 3 qui disparaitra lors de la moyenne
cdo mulc,.75 ${fileprec} ${pondprec}
cdo mulc,1.5 ${fileyear} ${pondyear}
cdo mulc,.75 ${filesuiv} ${pondsuiv}

# Fichier recevant trois ans consecutifs
pondtroisans=${workchemin}aerosols_${prec}0101_${suiv}1230_pond.nc

cdo mergetime ${pondprec} ${pondyear} ${pondsuiv} ${pondtroisans}
rm -f ${pondprec} ${pondyear} ${pondsuiv}

fileout=${workchemin}aerosols${year}_from_inca.nc

# Moyenne sur les trois ans, par mois
cdo ymonmean ${pondtroisans} ${fileout}
rm -f ${pondtroisans}

# Fix du vecteur-temps
ncks -A -v time_counter,time_centered,time_counter_bounds,time_centered_bounds ${fileyear} ${fileout}

# Fin de boucle sur les annees
done
